
# IP address of the MySQL database server 
HOST="panini-wiki.mariadb.database.azure.com"
# User name of the database server 
USER = "wikiadmin@panini-wiki"
# Password for the database user 
PASSWORD = "Pass@word2"
DATABASE_NAME = "wiki_temp"
ACCOUNT_NAME = "allmixedfilesforsearch"
ACCOUNT_KEY= "byw2umVaRocXLoDCDqkQBEmMl4IAbC1wBrRMGQq6b0H5DhIuneE/BJoz/FTVYIaGN1eI9K8NPjO00sFpEjt7NQ=="
CONTAINER_NAME="wiki"
